==> rosegarden-trinity_3.5.13.2.orig.tar.xz: rosegarden-trinity-3.5.13.2/src/gui/editors/segment/PlayListView.h <==
/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
 
    This program is Copyright 2000-2008
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>
 
    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.
 
    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_PLAYLISTVIEW_H_
#define _RG_PLAYLISTVIEW_H_

#include <klistview.h>

namespace Rosegarden {

class PlayListView : public KListView
{
public:
    PlayListView(TQWidget *parent=0, const char *name=0);

    TQListViewItem* previousSibling(TQListViewItem*);

protected:
//     virtual void dragEnterEvent(TQDragEnterEvent *event);
//     virtual void dropEvent(TQDropEvent*);

//     virtual void dragEnterEvent(TQDragEnterEvent*);
    virtual bool acceptDrag(TQDropEvent*) const;

    
};

}

#endif

==> rosegarden-trinity-14.0.8.tar.xz: rosegarden-trinity-14.0.8/src/gui/editors/segment/PlayListView.h <==
/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
 
    This program is Copyright 2000-2008
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>
 
    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.
 
    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_PLAYLISTVIEW_H_
#define _RG_PLAYLISTVIEW_H_

#include <tdelistview.h>

namespace Rosegarden {

class PlayListView : public TDEListView
{
public:
    PlayListView(TQWidget *parent=0, const char *name=0);

    TQListViewItem* previousSibling(TQListViewItem*);

protected:
//     virtual void dragEnterEvent(TQDragEnterEvent *event);
//     virtual void dropEvent(TQDropEvent*);

//     virtual void dragEnterEvent(TQDragEnterEvent*);
    virtual bool acceptDrag(TQDropEvent*) const;

    
};

}

#endif
